import stamp.core.*;
import stamp.util.text.*;
import stamp.peripheral.web.*;

/**
  Pink test program for sending email.
  Author: Peter Verkaik (peterverkaik@boselectro.nl)
  Date: 14 november 2005
*/

public class Pink_sendEmail_test {

  //Javelin pin assignments
  static final int pinRX = CPU.pin10;
  static final int pinTX = CPU.pin11;

  //Pink declarations
  static ScaledTimer16 pinkTimer = new ScaledTimer16(1000,100); //timeout is 1000 units, unit is 100*10uSec
  static Uart tx = new Uart(Uart.dirTransmit, pinTX, Uart.dontInvert, Uart.speed9600, Uart.stop1);
  static Uart rx = new Uart(Uart.dirReceive, pinRX, Uart.dontInvert, Uart.speed9600, Uart.stop1);
  static Pink myPink = new Pink('0',tx,rx,pinkTimer);

  //buffers
  static char[] buf = new char[65];

  /*
     Read and print range of PINK variables plus status and post.
  */
  static void readAll(int start, int n) {
    int p,s;
    while (n > 0) {
      p = myPink.readVar(start,buf,32767,0);
      Format.printf("%03d: ",start);
      if (p < 0) { //timeout
        Format.printf("TIMEOUT\n");
      }
      else {
        Format.printf("(bytes=%02d) ",p);
        Format.printf("%s\n",buf);
      }
      start++;
      n--;
    }
    s = myPink.getStatus();
    Format.printf("Status: ");
    if (s < 0) { //timeout
      Format.printf("TIMEOUT\n");
    }
    else {
      Format.printf("%08b\n",s);
      if (myPink.isUpdated()) {
        p = myPink.getPost();
        Format.printf("      : ");
        if (p < 0) { //timeout
          Format.printf("POST TIMEOUT\n");
        }
        else {
          Format.printf("Var_%02d POST update\n",p);
          p = myPink.readVar(p,buf,32767,0);
          if (p < 0) { //timeout
            Format.printf("      : TIMEOUT\n");
          }
          else {
            Format.printf("      : %s\n",buf);
          }
        }
      }
      if (myPink.isUdp()) {
        Format.printf("      : received udp message\n");
        p = myPink.readVar(Pink.Nb_varBM,buf,32767,0);
        Format.printf("      : ");
        if (p < 0) { //timeout
          Format.printf("UDP TIMEOUT\n");
        }
        else {
          Format.printf("(bytes=%d) ",p);
          Format.printf("%s\n",buf);
        }
      }
//      if (myPink.isConnected()) Format.printf("      : connected\n");
      if (myPink.isReady())     Format.printf("      : ready\n");
      if (myPink.isError())     Format.printf("      : error\n");
    }
  }

  //setup the email parameters (smtp,from,to) correctly before running this program
  static void main() {
    int n,count=1;
    Format.printf("Pink send email test program\n");
    Format.printf("Type a key to send an email\n");
    while (true) {
      if (Terminal.byteAvailable()) {
        Terminal.getChar(); //wait for key
        myPink.writeVar(Pink.Nb_varEV,"your.smtp.server");                // !! setup smtp server (must be valid smtp server)
        Format.sprintf(buf,"directly typed text %d",count);
        n = Format.strLen(buf);
        myPink.writeVar(Pink.Nb_varEC,buf,n,0);                           //contents
        Format.sprintf(buf,"pink email test %d",count++);
        n = Format.strLen(buf);
        myPink.writeVar(Pink.Nb_varES,buf,n,0);                           //subject
      myPink.writeVar(Pink.Nb_varEF,"fromYourFriend@friendISP.com");    // !! setup from (must be a valid existing email address
      myPink.writeVar(Pink.Nb_varET,"toYourEmailAddress@yourISP.com");  // !! setup to (your email address)
        Format.printf("sending email...\n");
        do {
          n = myPink.getStatus();
        } while ((n<0) || !myPink.isReady());
        myPink.sendEmail();
        do {
          n = myPink.getStatus();
          if (n>=0) Format.printf("Status: %08b\n",n);
        } while ((n<0) || !myPink.isReady());
        Format.printf("... done\n");
        readAll(100,7); //read the special variables
        Format.printf("Type a key to send an email\n");
      }
    }
  }

}